#!/usr/bin/env python

"""Tests for `file_provenance_utils` package."""


import unittest

from file_provenance_utils import file_provenance_utils


class TestFile_provenance_utils(unittest.TestCase):
    """Tests for `file_provenance_utils` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""
